@@ -2,21 +2,21 @@
 library(bioimagetools)
 
 ## ----readtif, warnings=FALSE, collapse=TRUE------------------------------
-cell <- readTIF("http://ex.volkerschmid.de/cell.tif")
+cell <- bioimagetools::readTIF("http://ex.volkerschmid.de/cell.tif")
 print(dim(cell))
 print(attributes(cell)$dim)
 print(attributes(cell)$bits.per.sample)
 par(pty="s")
-img(cell, z=25 ,col="rgb")
+bioimagetools::img(cell, z=25 ,col="rgb")
 
 ## ----writetif, warnings=FALSE, collapse=TRUE, cache=TRUE-----------------
 writeTIF(cell, file="my_cell.tif")
 
 ## ----readclasstif, warnings=FALSE, collapse=TRUE, cache=TRUE-------------
-writeTIF(2*EBImage::thresh(cell[,,1,])+EBImage::thresh(cell[,,2,]), file="simple.tif")
+bioimagetools::writeTIF(2*EBImage::thresh(cell[,,1,])+EBImage::thresh(cell[,,2,]), file="simple.tif")
 mysimple <- readClassTIF("simple.tif", n=3)
 par(pty="s")
-img(mysimple[,,25],col="red",up=3)
+bioimagetools::img(mysimple[,,25],col="red",up=3)
 
 ## ----remove, echo=FALSE--------------------------------------------------
 file.remove("my_cell.tif")
@@ -24,9 +24,9 @@ file.remove("simple.tif")
 
 ## ----img, warnings=FALSE, collapse=TRUE, cache=TRUE----------------------
 par(pty="s")
-img(cell, z=25, col="rgb")
-img(cell, z=25, col="r")
-img(cell, z=25, col="grey")
+bioimagetools::img(cell, z=25, col="rgb")
+bioimagetools::img(cell, z=25, col="r")
+bioimagetools::img(cell, z=25, col="grey")
 
 ## ----readMBP, warnings=FALSE, collapse=TRUE, cache=TRUE------------------
 bi<-readBMP(system.file(package = "bioimagetools","extdata", "V.bmp"))
